@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+from builtins import str
 import re
 
-from kinopoisk.utils import KinopoiskPage, KinopoiskImagesPage, get_request
+from ..utils import KinopoiskPage, KinopoiskImagesPage, get_request
 
 
 class PersonLink(KinopoiskPage):
@@ -47,13 +49,14 @@ class PersonMainPage(KinopoiskPage):
 
         content_info = re.compile(r'<tr\s*>\s*<td class="type">(.+?)</td>\s*<td[^>]*>(.+?)</td>\s*</tr>').findall(content)
         for name, value in content_info:
-            if name.encode('utf-8') == 'дата рождения':
+            if str(name) == 'дата рождения':
                 year_birth = re.compile(r'<a href="/lists/m_act%5Bbirthday%5D%5Byear%5D/\d{4}/">(\d{4})</a>').findall(value)
                 if year_birth:
                     instance.year_birth = self.prepare_int(year_birth[0])
 
         if instance.id:
             response = get_request(instance.get_url('info'))
+            response.connection.close()
             if response.content:
                 instance.information = response.content.decode('windows-1251', 'ignore').replace(' class="trivia"', '')
 
