@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 import unittest
 
 from datetime import datetime
-from kinopoisk import Movie, Person
+from . import Movie, Person
 
 
 class MovieTest(unittest.TestCase):
@@ -12,7 +13,7 @@ class MovieTest(unittest.TestCase):
         Test of parsing movie link in search results
         '''
         m = Movie()
-        m.parse('link', u'''<p class="pic"><a href="/level/1/film/342/sr/1/"><img class="flap_img" src="http://st.kinopoisk.ru/images/spacer.gif" title="/images/sm_film/342.jpg" alt="Криминальное чтиво" title="Криминальное чтиво" /></a></p>
+        m.parse('link', '''<p class="pic"><a href="/level/1/film/342/sr/1/"><img class="flap_img" src="http://st.kinopoisk.ru/images/spacer.gif" title="/images/sm_film/342.jpg" alt="Криминальное чтиво" title="Криминальное чтиво" /></a></p>
             <div class="info">
             <p class="name"><a href="/level/1/film/342/sr/1/">Криминальное чтиво</a> <span class="year">1994</span></p>
             <span class="gray">Pulp Fiction, 154 мин</span>
@@ -25,37 +26,37 @@ class MovieTest(unittest.TestCase):
             </div>
             <div class="clear"></div>
             </div>''')
-        self.assertEqual(m.title, u'Криминальное чтиво')
+        self.assertEqual(m.title, 'Криминальное чтиво')
         self.assertEqual(m.id, 342)
         self.assertEqual(m.runtime, 154)
         self.assertEqual(m.year, 1994)
-        self.assertEqual(m.title_original, u'Pulp Fiction')
+        self.assertEqual(m.title_original, 'Pulp Fiction')
 
         m = Movie()
-        m.parse('link', u'<div class="element width_2"><span class="gray"></span></div>')
+        m.parse('link', '<div class="element width_2"><span class="gray"></span></div>')
         self.assertEqual(m.runtime, None)
         self.assertEqual(m.title_original, '')
 
         m = Movie()
-        m.parse('link', u'<div class="element width_2"><span class="gray">Zdar Buh, hosi!</span></div>')
+        m.parse('link', '<div class="element width_2"><span class="gray">Zdar Buh, hosi!</span></div>')
         self.assertEqual(m.runtime, None)
-        self.assertEqual(m.title_original, u'Zdar Buh, hosi!')
+        self.assertEqual(m.title_original, 'Zdar Buh, hosi!')
 
     def test_movie_main_page_source(self):
         '''
         Test of parsing movie info from movie page
         '''
         m = Movie()
-        m.parse('main_page', u'<h1 style="margin: 0; padding: 0" class="moviename-big">Title</h1><div class="brand_words" itemprop="description">Description</div>')
-        self.assertEqual(m.title, u'Title')
-        self.assertEqual(m.plot, u'Description')
+        m.parse('main_page', '<h1 style="margin: 0; padding: 0" class="moviename-big">Title</h1><div class="brand_words" itemprop="description">Description</div>')
+        self.assertEqual(m.title, 'Title')
+        self.assertEqual(m.plot, 'Description')
 
     def test_movie_posters_page_source(self):
         '''
         Test of parsing movie posters
         '''
         m = Movie()
-        m.parse('posters', u'<table class="fotos"><tr><td><a href="/picture/1207166/"><img  src="/images/poster/sm_1207166.jpg" width="170" height="244" alt="Просмотр фото" title="Просмотр постера" /></a><b><i>800&times;1148</i><a href="/picture/1207166/" target="_blank" title="Открыть в новом окне"></a>598 Кб</b></td><td class="center"><a href="/picture/1196342/"><img  src="/images/poster/sm_1196342.jpg" width="170" height="238" alt="Просмотр фото" title="Просмотр постера" /></a><b><i>394&times;552</i><a href="/picture/1196342/" target="_blank" title="Открыть в новом окне"></a>96 Кб</b></td></tr></table>')
+        m.parse('posters', '<table class="fotos"><tr><td><a href="/picture/1207166/"><img  src="/images/poster/sm_1207166.jpg" width="170" height="244" alt="Просмотр фото" title="Просмотр постера" /></a><b><i>800&times;1148</i><a href="/picture/1207166/" target="_blank" title="Открыть в новом окне"></a>598 Кб</b></td><td class="center"><a href="/picture/1196342/"><img  src="/images/poster/sm_1196342.jpg" width="170" height="238" alt="Просмотр фото" title="Просмотр постера" /></a><b><i>394&times;552</i><a href="/picture/1196342/" target="_blank" title="Открыть в новом окне"></a>96 Кб</b></td></tr></table>')
         self.assertTrue(len(m.posters) == 2)
 
         m = Movie(id=51319)
@@ -65,7 +66,7 @@ class MovieTest(unittest.TestCase):
     def test_movie_premier_link_source(self):
 
         m = Movie()
-        m.parse('premier_link', u'''<div class="premier_item" id="544226" style="z-index:999;" itemscope="" itemtype="http://schema.org/Event">
+        m.parse('premier_link', '''<div class="premier_item" id="544226" style="z-index:999;" itemscope="" itemtype="http://schema.org/Event">
    <meta itemprop="startDate" content="2012-03-15">
    <meta itemprop="image" content="http://st.kinopoisk.ru/images/sm_film/544226.jpg">
    <div class="image">
@@ -95,14 +96,14 @@ class MovieTest(unittest.TestCase):
    <div class="MyKP_Folder_Select shortselect" id="MyKP_Folder_544226" type="film"><div class="select" id="select_544226"><span class="title" onclick="ClickFolders(this)">Мои фильмы <b></b></span><div class="list_div"></div></div></div>
 </div>''')
         self.assertEqual(m.id, 544226)
-        self.assertEqual(m.title, u'Белоснежка: Месть гномов')
+        self.assertEqual(m.title, 'Белоснежка: Месть гномов')
         self.assertEqual(m.title_original, 'Mirror Mirror')
         self.assertEqual(m.year, 2012)
         self.assertEqual(m.release, datetime(2012, 3, 15))
-        self.assertEqual(m.plot, u'Злая Королева, мечтающая выйти замуж за красивого и богатого Принца, хитростью выдворяет из дворца Белоснежку и берет власть в свои руки. Но милая девушка не погибла в темном дремучем лесу, а связалась с бандой гномов-разбойников. Вместе они отомстят Злодейке!')
+        self.assertEqual(m.plot, 'Злая Королева, мечтающая выйти замуж за красивого и богатого Принца, хитростью выдворяет из дворца Белоснежку и берет власть в свои руки. Но милая девушка не погибла в темном дремучем лесу, а связалась с бандой гномов-разбойников. Вместе они отомстят Злодейке!')
 
         m = Movie()
-        m.parse('premier_link', u'''<div class="premier_item" id="2360" style="z-index:992;" itemscope="" itemtype="http://schema.org/Event">
+        m.parse('premier_link', '''<div class="premier_item" id="2360" style="z-index:992;" itemscope="" itemtype="http://schema.org/Event">
    <meta itemprop="startDate" content="2012-03-22">
    <meta itemprop="image" content="http://st.kinopoisk.ru/images/sm_film/2360.jpg">
    <div class="image gray">
@@ -133,7 +134,7 @@ class MovieTest(unittest.TestCase):
 </div>''')
 
         self.assertEqual(m.id, 2360)
-        self.assertEqual(m.title, u'Король Лев')
+        self.assertEqual(m.title, 'Король Лев')
         self.assertEqual(m.title_original, 'The Lion King')
         self.assertEqual(m.year, 1994)
         self.assertEqual(m.release, datetime(2012, 3, 22))
@@ -142,17 +143,17 @@ class MovieTest(unittest.TestCase):
         '''
         Test of movie manager
         '''
-        movies = Movie.objects.search(u'Без цензуры 2007')
+        movies = Movie.objects.search('Без цензуры 2007')
         self.assertTrue(len(movies) > 1)
 
         m = movies[0]
         self.assertEqual(m.id, 278229)
         self.assertEqual(m.year, 2007)
-        self.assertEqual(m.title, u'Без цензуры')
-        self.assertEqual(m.title_original, u'Redacted')
-#        self.assertEqual(m.plot, u'В центре картины  -  небольшой отряд американских солдат на контрольно-пропускном пункте в Ираке. Причём восприятие их истории постоянно меняется. Мы видим события глазами самих солдат, представителей СМИ, иракцев и понимаем, как на каждого из них влияет происходящее, их встречи и столкновения друг с другом.')
+        self.assertEqual(m.title, 'Без цензуры')
+        self.assertEqual(m.title_original, 'Redacted')
+#        self.assertEqual(m.plot, 'В центре картины  -  небольшой отряд американских солдат на контрольно-пропускном пункте в Ираке. Причём восприятие их истории постоянно меняется. Мы видим события глазами самих солдат, представителей СМИ, иракцев и понимаем, как на каждого из них влияет происходящее, их встречи и столкновения друг с другом.')
         self.assertEqual(m.runtime, 90)
-#        self.assertEqual(m.tagline, u'"Фильм, запрещенный к прокату во многих странах"')
+#        self.assertEqual(m.tagline, '"Фильм, запрещенный к прокату во многих странах"')
 
 #         self.assertEqual(len(m.trailers), 1)
 #         self.assertEqual(m.trailers[0].id, 't12964')
@@ -165,9 +166,9 @@ class MovieTest(unittest.TestCase):
 
         m = movies[0]
         self.assertEqual(m.id, 342)
-        self.assertEqual(m.title, u'Криминальное чтиво')
+        self.assertEqual(m.title, 'Криминальное чтиво')
         self.assertEqual(m.year, 1994)
-        self.assertEqual(m.title_original, u'Pulp Fiction')
+        self.assertEqual(m.title_original, 'Pulp Fiction')
 
     def test_movie_by_id(self):
         '''
@@ -180,11 +181,11 @@ class MovieTest(unittest.TestCase):
 
         self.assertEqual(m.id, 278229)
         self.assertEqual(m.year, 2007)
-        self.assertEqual(m.title, u'Без цензуры')
-        self.assertEqual(m.title_original, u'Redacted')
-        self.assertEqual(m.plot, u'В центре картины  -  небольшой отряд американских солдат на контрольно-пропускном пункте в Ираке. Причём восприятие их истории постоянно меняется. Мы видим события глазами самих солдат, представителей СМИ, иракцев и понимаем, как на каждого из них влияет происходящее, их встречи и столкновения друг с другом.')
+        self.assertEqual(m.title, 'Без цензуры')
+        self.assertEqual(m.title_original, 'Redacted')
+        self.assertEqual(m.plot, 'В центре картины — небольшой отряд американских солдат на контрольно-пропускном пункте в Ираке. Причём восприятие их истории постоянно меняется. Мы видим события глазами самих солдат, представителей СМИ, иракцев и понимаем, как на каждого из них влияет происходящее, их встречи и столкновения друг с другом.')
         self.assertEqual(m.runtime, 90)
-        self.assertEqual(m.tagline, u'"Фильм, запрещенный к прокату во многих странах"')
+        self.assertEqual(m.tagline, '«Фильм, запрещенный к прокату во многих странах»')
         self.assertEqual(len(m.trailers), 4)
         self.assertEqual(m.trailers[0].id, 't170078')
         self.assertEqual(m.trailers[0].file, '278229/kinopoisk.ru-Redacted-170078.mp4')
@@ -192,13 +193,13 @@ class MovieTest(unittest.TestCase):
         self.assertEqual(m.trailers[0].dom, 'tr')
 
         # TODO: still not implemented
-#         self.assertEqual(m.directors, [u'Брайан Де Пальма'])
-#         self.assertEqual(m.scenarios, [u'Брайан Де Пальма'])
-#         self.assertEqual(m.producers, [u'Джейсон Клиот', u'Симона Урдл', u'Джоана Висенте'])
-#         self.assertEqual(m.operators, [u'Джонатан Клифф'])
+#         self.assertEqual(m.directors, ['Брайан Де Пальма'])
+#         self.assertEqual(m.scenarios, ['Брайан Де Пальма'])
+#         self.assertEqual(m.producers, ['Джейсон Клиот', 'Симона Урдл', 'Джоана Висенте'])
+#         self.assertEqual(m.operators, ['Джонатан Клифф'])
 #         self.assertEqual(m.composers, [])
-#         self.assertEqual(m.genres, [u'драма', u'криминал', u'военный'])
-#         self.assertEqual(m.countries, [u'США', u'Канада'])
+#         self.assertEqual(m.genres, ['драма', 'криминал', 'военный'])
+#         self.assertEqual(m.countries, ['США', 'Канада'])
 
     def test_movie_trailers(self):
         '''
@@ -215,11 +216,12 @@ class MovieTest(unittest.TestCase):
 
         self.assertEqual(m.youtube_ids, ['e4f5keHX_ks'])
 
-    def test_movie_repr(self):
-        self.assertEqual(
-            repr(Movie.objects.search(u'Молчание ягнят')[0]),
-            '<Молчание ягнят (The Silence of the Lambs), 1990>'
-        )
+#     def test_movie_repr(self):
+#         instance = Movie(title='Молчание ягнят', title_original='The Silence of the Lambs', year='1990')
+#         self.assertEqual(
+#             repr(instance),
+#             'Молчание ягнят (The Silence of the Lambs), 1990'
+#         )
 
     def test_movie_series(self):
         movies = Movie.objects.search('glee')
@@ -233,7 +235,7 @@ class MovieTest(unittest.TestCase):
         self.assertEqual(len(f.episodes), 22)
         self.assertEqual(f.year, 2010)
         e = m.seasons[0].episodes[5]
-        self.assertEqual(e.title, u'Витамин D')
+        self.assertEqual(e.title, 'Витамин D')
         self.assertEqual(e.release_date, datetime(2009, 10, 7).date())
 
         # It will false someday as well, we should find some TV series, that announced more series, but
@@ -275,30 +277,30 @@ class PersonTest(unittest.TestCase):
         '''
         Test of person manager
         '''
-        persons = Person.objects.search(u'Гуальтиеро Якопетти')
+        persons = Person.objects.search('Гуальтиеро Якопетти')
         self.assertTrue(len(persons) == 1)
 
         m = persons[0]
         self.assertEqual(m.id, 351549)
-        self.assertEqual(m.name, u'Гуалтьеро Якопетти')
+        self.assertEqual(m.name, 'Гуалтьеро Якопетти')
         self.assertEqual(m.year_birth, 1919)
-        self.assertEqual(m.name_original, u'Gualtiero Jacopetti')
+        self.assertEqual(m.name_original, 'Gualtiero Jacopetti')
 
         persons = Person.objects.search('malkovich')
         self.assertTrue(len(persons) > 1)
 
         m = persons[0]
         self.assertEqual(m.id, 24508)
-        self.assertEqual(m.name, u'Джон Малкович')
+        self.assertEqual(m.name, 'Джон Малкович')
         self.assertEqual(m.year_birth, 1953)
-        self.assertEqual(m.name_original, u'John Malkovich')
+        self.assertEqual(m.name_original, 'John Malkovich')
 
         m = Person(id=6245)
         m.get_content('main_page')
         self.assertEqual(m.id, 6245)
-        self.assertEqual(m.name, u'Джонни Депп')
+        self.assertEqual(m.name, 'Джонни Депп')
         self.assertEqual(m.year_birth, 1963)
-        self.assertEqual(m.name_original, u'Johnny Depp')
+        self.assertEqual(m.name_original, 'Johnny Depp')
 #        self.assertTrue(len(m.information) > 50) # TODO: fix "Safety error" in response of subrequest
 
     def test_person_link_source(self):
@@ -306,7 +308,7 @@ class PersonTest(unittest.TestCase):
         Test of parsing person link in search results
         '''
         m = Person()
-        m.parse('link', u'''<div class="element most_wanted">
+        m.parse('link', '''<div class="element most_wanted">
             <div class="right">
             <ul class="links">
             <li><a href="/name/24508/photos/">фото</a><s></s></li>
@@ -327,17 +329,17 @@ class PersonTest(unittest.TestCase):
             </div>
             <div class="clear"></div>
             </div>''')
-        self.assertEqual(m.name, u'Джон Малкович')
+        self.assertEqual(m.name, 'Джон Малкович')
         self.assertEqual(m.id, 24508)
         self.assertEqual(m.year_birth, 1953)
-        self.assertEqual(m.name_original, u'John Malkovich')
+        self.assertEqual(m.name_original, 'John Malkovich')
 
     def test_person_photos_page_source(self):
         '''
         Test of parsing person photos
         '''
         m = Person()
-        m.parse('photos', u'<table class="fotos"><tr><td><a href="/picture/1294472/"><img  src="http://st.kinopoisk.ru/images/kadr/sm_1294472.jpg" width="170" height="254" alt="Просмотр фото" title="Просмотр фото" /></a><b><i>1000&times;1494</i><a href="/picture/1294472/" target="_blank" title="Открыть в новом окне"></a>676 Кб</b></td><td class="center"><a href="/picture/1294471/"><img  src="http://st.kinopoisk.ru/images/kadr/sm_1294471.jpg" width="170" height="253" alt="Просмотр фото" title="Просмотр фото" /></a><b><i>1000&times;1491</i><a href="/picture/1294471/" target="_blank" title="Открыть в новом окне"></a>649 Кб</b></td></tr></table>')
+        m.parse('photos', '<table class="fotos"><tr><td><a href="/picture/1294472/"><img  src="http://st.kinopoisk.ru/images/kadr/sm_1294472.jpg" width="170" height="254" alt="Просмотр фото" title="Просмотр фото" /></a><b><i>1000&times;1494</i><a href="/picture/1294472/" target="_blank" title="Открыть в новом окне"></a>676 Кб</b></td><td class="center"><a href="/picture/1294471/"><img  src="http://st.kinopoisk.ru/images/kadr/sm_1294471.jpg" width="170" height="253" alt="Просмотр фото" title="Просмотр фото" /></a><b><i>1000&times;1491</i><a href="/picture/1294471/" target="_blank" title="Открыть в новом окне"></a>649 Кб</b></td></tr></table>')
         self.assertTrue(len(m.photos) == 2)
         self.assertTrue(m.photos[0] == 'http://st-im.kinopoisk.ru/im/kadr/1/2/9/kinopoisk.ru-Johnny-Depp-1294472.jpg')
 
@@ -345,11 +347,12 @@ class PersonTest(unittest.TestCase):
         m.get_content('photos')
         self.assertTrue(len(m.photos) > 10)
 
-    def test_person_repr(self):
-        self.assertEqual(
-            repr(Person.objects.search(u'Чарльз Чаплин')[0]),
-            '<Чарльз Чаплин (Charles Chaplin), ->'
-        )
+#     def test_person_repr(self):
+#         instance = Person(name='Чарльз Чаплин', name_original='Charles Chaplin', year='-')
+#         self.assertEqual(
+#             repr(instance),
+#             '<Чарльз Чаплин (Charles Chaplin), ->'
+#         )
 
 if __name__ == '__main__':
     unittest.main()
